pub struct Executor { /* private fields */ }Expand description
Executor for asynchronous tasks
Implementations
Sourceimpl Executor
impl Executor
Sourcepub fn new(threads: usize, monitor_port: Option<u16>) -> Self
pub fn new(threads: usize, monitor_port: Option<u16>) -> Self
Creates a new Executor with a number of threads
Sourcepub fn spawn_with_name<T: Into<Task>, S: Into<String>>(&self, task: T, _name: S)
pub fn spawn_with_name<T: Into<Task>, S: Into<String>>(&self, task: T, _name: S)
Start a task on an executor thread, specifying its name for the monitor
pub fn join_arc(this: Arc<Self>) -> Result<()>